pub(crate) fn live_locals_at(
tcx: TyCtxt<'_>,
caller: DefId,
call_block: BasicBlock,
statement_index: usize,
seed_params: bool,
track_moves: bool,
) -> HashSet<Local>Expand description
Compute the set of locals that are live (between StorageLive and
StorageDead) at the deref point (call_block, statement_index), scanning
the function in execution order up to that point. Used by the callsite
shared-XOR-mutable check to ignore temporaries that have already gone dead
(e.g. a method call’s &self receiver).